Mention @some-bodies_name

Mention some-bodies_name/some_repository

Mention facelessuser/some_repository

Commit some-bodies_name/some_repository@3f6b07a

Compare some-bodies_name/some_repository@e2ed7e0...90b6fb8

Issue some-bodies_name/some_repository#33

Pull request some-bodies_name/some_repository!33

Commit 3f6b07a

Compare e2ed7e0...90b6fb8

Issue #33

Pull request !33

Commit MyRepo@3f6b07a

Compare MyRepo@e2ed7e0...90b6fb8

Issue MyRepo#33

Pull MyRepo!33

Mention @some-user

Mention some-bodies_name/some_repository

Mention facelessuser/some_repository

Issue some-user/some-repo#1

Pull request some-user/some-repo!2

Commit some-user/some-repo@3f6b07a8

Compare some-user/some-repo@e2ed7e0b...90b6fb87

Mention facelessuser/.repo

Mention .repo#3

.repo#3

some-user/.repo#3

@username

No issue #33

No issue #

No pull request !33

No mention @some-bodies_name

No issue some-bodies_name/some_repository#33

No pull request some-bodies_name/some_repository!33

No commit @3f6b07a8eeaa9d606115758d90f55fec565d4e2a

No compare @e2ed7e0b3973f3f9eb7a26b8ef7ae514eebfe0d2...90b6fb8

No mention @facelessuser

No issue #33

No issue some-bodies_name/some_repository#33

@facelessuser

No repo @facelessuser/pymdown-extensions

No link http://google.com

No email fakeemail@mail.com